SGB advisor output

# You can consider taking a look at the following SGBs:

This is not investment advise.

The data in table could be wrong due to errors with source data, calculation, timing or other reasons. Please do your own research.

PROFITS ARE NOT GUARANTEED. LOSSES CAN BE UPTO 100%!

XIRR shown is only for interest payments. Please read assumptions made below the table

## Disclaimer

This is just a tool to maximize XIRR on interest payments, and to find possible arbritages between gold price IRL and the prices SGBs are trading at

Assumptions made to calculate the XIRR

- The price of Gold when the SGB matures will be the same as it is today. While this may sound dumb, any increase in the price of gold should lead to a somewhat similar increase in redemption prices of all SGBs. You way think that gold can fall or increase in between, but that will affect all gold investments, not just SGB
- You are interested in gold and have finalized on SGB as a product, and are just confused among different SGBs